.. image:: https://travis-ci.org/joommf/oommfc.svg?branch=master
   :target: https://travis-ci.org/joommf/oommfc
   :align: right

.. image:: https://codecov.io/gh/joommf/oommfc/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/joommf/oommfc
   :align: right

.. image:: https://readthedocs.org/projects/oommfc/badge/?version=latest
   :target: http://oommfc.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://badge.fury.io/py/oommfc.svg
   :target: https://badge.fury.io/py/oommfc

A Python-based OOMMF calculator.

Authors: Marijan Beg, Ryan Pepper, Hans Fangohr
